@@ -1,12 +1,12 @@
-//@line 37 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 37 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 41 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
-//@line 44 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 44 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
-//@line 50 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 50 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 pref("general.startup.browser", true);
 
@@ -29,13 +29,15 @@ pref("extensions.logging.enabled", false);
 pref("extensions.hideInstallButton", true);
 
 // Preferences for the Get Add-ons pane
-pref("extensions.getAddons.showPane", true);
-pref("extensions.getAddons.browseAddons", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%");
+pref ("extensions.getAddons.showPane", false);
+pref ("extensions.getAddons.browseAddons", "http://www.gnu.org/software/gnuzilla/addons.html");
 pref("extensions.getAddons.maxResults", 5);
-pref("extensions.getAddons.recommended.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/recommended");
-pref("extensions.getAddons.recommended.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/list/featured/all/10/%OS%/%VERSION%");
-pref("extensions.getAddons.search.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/search?q=%TERMS%");
-pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/10/%OS%/%VERSION%");
+pref ("extensions.getAddons.recommended.browseURL", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref ("extensions.getAddons.recommended.url", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref ("extensions.getAddons.search.browseURL", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref ("extensions.getAddons.search.url", "http://www.gnu.org/software/gnuzilla/addons.html");
+
+
 
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
@@ -44,7 +46,7 @@ pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID
 pref("extensions.blocklist.detailsURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/blocklist/");
 
 // Dictionary download preference
-pref("browser.dictionaries.download.url", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/firefox/%VERSION%/dictionaries/");
+pref("browser.dictionaries.download.url", "http://gnuzilla.gnu.org");
 
 // App-specific update preferences
 
@@ -118,9 +120,9 @@ pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/Ve
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
                                             // Themes every day
 // Non-symmetric (not shared by extensions) extension-specific [update] preferences
-pref("extensions.getMoreExtensionsURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/extensions/");
-pref("extensions.getMoreThemesURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/themes/");
-pref("extensions.getMorePluginsURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/plugins/");
+pref("extensions.getMoreExtensionsURL", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref("extensions.getMoreThemesURL", "http://www.gnu.org/software/gnuzilla/addons.html");
+pref("extensions.getMorePluginsURL", "http://gnuzilla.gnu.org/");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
                                                 // restart.
@@ -133,12 +135,12 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "IceCat/3.0.6-g1");
+pref("general.useragent.extra.firefox", "IceCat/3.0.7-g1");
 
 pref("general.smoothScroll", false);
-//@line 180 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 182 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 184 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 186 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -159,11 +161,11 @@ pref("browser.warnOnRestart", true);
 pref("browser.fullscreen.autohide", true);
 pref("browser.fullscreen.animateUp", 1);
 
-//@line 205 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 207 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 210 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 212 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("browser.urlbar.doubleClickSelectsAll", true);
-//@line 214 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 216 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("browser.urlbar.autoFill", false);
 pref("browser.urlbar.matchOnlyTyped", false);
 // 0: Match anywhere (e.g., middle of words)
@@ -299,9 +301,9 @@ pref("browser.bookmarks.max_backups",             5);
 
 // Scripts & Windows prefs
 pref("dom.disable_open_during_load",              true);
-//@line 353 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 355 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("javascript.options.showInConsole",          false);
-//@line 355 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 357 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 // Make the status bar reliably present and unaffected by pages
 pref("dom.disable_window_open_feature.status",    true);
@@ -356,7 +358,7 @@ pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.proper
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 423 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 425 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.numlines",1);
@@ -366,7 +368,7 @@ pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withmetakey.action",0);
 pref("mousewheel.withmetakey.sysnumlines",true);
 pref("mousewheel.withmetakey.numlines",1);
-//@line 433 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 435 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withcontrolkey.numlines",1);
@@ -426,11 +428,11 @@ pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.
 // by default we show an infobar message when pages require plugins the user has not installed
 pref("plugins.hide_infobar_for_missing_plugin", false);
 
-//@line 495 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 497 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 500 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 502 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 502 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 504 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -443,9 +445,9 @@ pref("bidi.browser.ui", false);
 // 0 goes Back/Forward
 // 1 act like PgUp/PgDown
 // 2 and other values, nothing
-//@line 515 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 517 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("browser.backspace_action", 2);
-//@line 519 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 521 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 // this will automatically enable inline spellchecking (if it is available) for
 // editable elements in HTML
@@ -518,7 +520,7 @@ pref("gecko.handlerService.schemes.mailto.3.uriTemplate", "chrome://browser-regi
 // By default, we don't want protocol/content handlers to be registered from a different host, see bug 402287
 pref("gecko.handlerService.allowRegisterFromDifferentHost", false);
 
-//@line 592 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 594 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 // Safe browsing does nothing unless this pref is set
 pref("browser.safebrowsing.enabled", true);
 
@@ -565,23 +567,23 @@ pref("urlclassifier.gethashtables", "goog-phish-shavar,goog-malware-shavar");
 // the database.
 pref("urlclassifier.confirm-age", 2700);
 
-//@line 644 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 646 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 // Maximum size of the sqlite3 cache during an update, in bytes
-//@line 647 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 649 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 pref("urlclassifier.updatecachemax", 104857600);
-//@line 651 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 653 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 // URL for checking the reason for a malware warning.
 pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/diagnostic?client=%NAME%&hl=%LOCALE%&site=");
 
-//@line 656 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 658 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 pref("browser.EULA.version", 3);
 pref("browser.rights.version", 3);
 pref("browser.rights.3.shown", false);
 
-//@line 665 "/icecat-3.0.6-g1/browser/app/profile/firefox.js"
+//@line 667 "/icecat-3.0.7-g1/browser/app/profile/firefox.js"
 
 pref("browser.sessionstore.enabled", true);
 pref("browser.sessionstore.resume_from_crash", true);
